@@ -4,11 +4,11 @@ from starlette import status
 
 from rowantree.common.sdk import demand_env_var
 
-from ..contracts.dto.authenticate_user_request import AuthenticateUserRequest
 from ..contracts.dto.request_status_codes import RequestStatusCodes
 from ..contracts.dto.token import Token
 from ..contracts.dto.wrapped_request import WrappedRequest
 from ..contracts.request_verb import RequestVerb
+from ..contracts.requests.authenticate_user_request import AuthenticateUserRequest
 from .abstract_command import AbstractCommand
 
 
